<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Остання перевірка:</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Якщо ви вийдете з програми тестування, ви більше не отримуватимете тестових оновлень.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вийти</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation>Переглянути журнал оновлення</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Журнал оновлень</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>Немає журналу оновлень</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Оновлення системи</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Оновлення захисту</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Накопичувальне оновлення драйверів із включенням нових можливостей, оновленнями якості та оновленнями захисту</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Надає оновлення захисту</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Дата встановлення:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Переглянути подробиці</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Час випуску:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Згорнути</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Версія:</translation>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation>Журнал оновлення</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation>Експортувати до стільниці</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>НЕМАЄ</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>НИЗЬКИЙ</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>СЕРЕДНІЙ</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>ВИСОКИЙ</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>КРИТИЧНИЙ</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>критичний-ризик</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>високий-ризик</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>середній-ризик</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>низький-ризик</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>невідомий</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Це оновлення виправляє</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>вразливостей</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>вразливість</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 з %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>,</translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>щоб дізнатися більше, будь ласка, відвідайте</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Перевірка оновлень, будь ласка зачекайте...</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Ваша система оновлена</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Невідома помилка</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>Не вдалося отримати оновлення. Будь ласка, звільніть на диску принаймні %1.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Помилка у залежностях. Не вдалося виявити оновлення.</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Будь ласка, перевірте, чи працює мережа і повторіть спробу.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>Не вдалося отримати оновлення. Будь ласка, перевірте, чи є працездатною мережа, і повторіть спробу.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Не вдалося виконати резервне копіювання системи. Якщо продовжити процедуру оновлення, ви не зможете повернутися до попереднього стану системи пізніше.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Якщо ви продовжите процедуру оновлення, ви не зможете повернутися до попередньої системи.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Недостатньо місця на диску</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Помилка DPKG</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Не вистачає файла</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>Нештатне з&apos;єднання зі службою. Будь ласка, перевірте працездатність мережі і повторіть спробу</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>Налаштування джерела сховища є некоректним. Будь ласка, перевірте налаштування і повторіть спробу.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Перевірити знову</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Правила конфіденційності</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Щоб користуватися програмним забезпеченням, вам слід погодитися із %1, яка є супутньою до оновлень програмного забезпечення.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Увімкніть пункти у розділі «Оновлення даних», щоб оптимізувати роботу</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Вашу систему не активовано, і вона не змогла встановити з&apos;єднання зі службами оновлення</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>Оновлення системи вимкнено. Будь ласка, зв&apos;яжіться із адміністратором для довідки.</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation>У системі увімкнено функціональну можливість автоматичного відновлення і не передбачено підтримки оновлень. Якщо у вас є якісь питання, будь ласка, зв&apos;яжіться із промисловим адміністратором.</translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation>Оновлення вже отримано. Що робити?</translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation>Автономне встановлення</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Оновити і перезавантажити</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Оновити і вимкнути</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Інтелектуальне перемикання дзеркал</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Тип оновлення</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Функціональне оновлення</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Накопичувальне оновлення драйверів із включенням нових можливостей, оновленнями якості та оновленнями захисту</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Оновлення захисту</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Надає оновлення захисту</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Сторонні оновлення</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Надає оновлення для додаткових джерел сховищ</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Обмеження швидкості</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Параметр обмеження</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Автоматичне отримання</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Вмикання «Автоматичного отримання» призведе до автоматичного отримання оновлень, якщо встановлено з&apos;єднання з інтернетом</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Отримувати, якщо неактивна</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Починається</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Завершується</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Додаткові параметри</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Сповіщення щодо оновлень</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Спорожнити кеш пакунків</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Журнал оновлень</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Переглянути</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Долучитися до каналу внутрішнього тестування</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Натисніть тут, щоб завершити подання</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Розгорнути</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Згорнути</translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation>Можна використовувати лише числа у діапазоні 1-99999</translation>
    </message>
    <message>
        <source>Join the internal testing channel to get deepin latest updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Оновлення системи</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Виправлено деякі відомі вади та недоліки захисту</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Оновлення безпеки</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Сторонні сховища</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation>журнал_оновлення</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Не вдалося експортувати журнал. Будь ласка, повторіть спробу</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Журнал було експортовано до стільниці</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Оновлення</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Будь ласка, з&apos;єднайте комп&apos;ютер з джерелом живлення, потім встановлюйте оновлення.</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Оновлення системи</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Оновлення пакунків та самої системи</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Налаштування Оновлення</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Встановлення</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Отримання оновлень завершено</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Встановити оновлення</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Розмір оновлення:</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Не вдалося отримати оновлення</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Отримуємо оновлення…</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Отримання</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Налаштування параметрів оновлення. Оновлення захисту, Автоматичне отримання оновлень та сповіщення щодо оновлень</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Перезавантажити зараз</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Отримати</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Встановлення оновлень…</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Спробувати ще раз</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Продовжити оновлення</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Доступні оновлення</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Не вдалося встановити оновлення</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Для забезпечення належної роботи вашої системи і програм, будь ласка, перезавантажте систему після оновлення</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Створюємо резервну копію…</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Виконуємо створення резервної копії</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Не вдалося створити резервну копію</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Успішне встановлення оновлень</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Якщо ви продовжите процедуру оновлення, ви не зможете повернутися до попередньої системи.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Повторити спробу</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Перейти до оновлення</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>Батарею заряджено менше ніж на 60%. Для успішного оновлення, будь ласка, з&apos;єднайте пристрій із джерелом струму.</translation>
    </message>
</context>
</TS>